@@ -27,14 +27,16 @@ my $rules = {
         },
     },
 };
+my $opts = { pass => 'locate' };
 
-my $converter = Hash::Convert->new($rules);
+my $converter = Hash::Convert->new($rules, $opts);
 
 my $before = {
     created_at => time,
     count      => 1,
     name       => 'hixi',
     mail       => 'hixi@cpan.org',
+    locate     => 'JP',
     item => {
         name     => 'chocolate',
         cost     => 100,
@@ -50,5 +52,6 @@ print Dumper $after;
 #    },
 #    'count' => 2,
 #    'visit' => '1377019766',
-#    'price' => 90
+#    'price' => 90,
+#    'locate' => 'JP'
 #}
